@@ -1,10 +1,5 @@
-# ovirt-imageio
-# Copyright (C) 2018 Red Hat, Inc.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-FileCopyrightText: Red Hat, Inc.
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 import errno
 import io
@@ -24,7 +19,6 @@ from ovirt_imageio._internal import qemu_nbd
 from . import backup
 from . import ci
 from . import distro
-from . import storage
 from . import testutil
 
 from . marks import (
@@ -47,7 +41,8 @@ log = logging.getLogger("test")
     ids=str
 )
 def user_file(request):
-    with storage.Backend(request.param) as backend:
+    backend = request.param
+    with backend:
         yield backend
 
 
